<?php

/**
 * @file
 * Contains \Drupal\smartlook_tracking\Form\SmartlookAdminSettingsForm class.
 */

namespace Drupal\smartlook_tracking\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Smartlook settings for this site.
 */
class SmartlookAdminSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'smartlook_tracking_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['smartlook_tracking.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('smartlook_tracking.settings');

    $form['general'] = [
      '#type'  => 'details',
      '#title' => $this->t('General settings'),
      '#open'  => TRUE,
    ];

    $form['general']['smartlook_tracking_account'] = [
      '#type'          => 'textfield',
      '#title'         => $this->t('Smartlook ID'),
      '#description'   => $this->t('This ID is unique to each site you want to track separately. To get a Smartlook ID, <a href=":link">register your site with Smartlook</a>.', [
        ':link' => 'https://www.smartlook.com',
      ]),
      '#maxlength'     => 40,
      '#size'          => 40,
      '#default_value' => $config->get('account'),
      '#required'      => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    // Trim some text values.
    $form_state->setValue('smartlook_tracking_account', trim($form_state->getValue('smartlook_tracking_account')));

    if (strlen($form_state->getValue('smartlook_tracking_account')) != 40) {
      $form_state->setErrorByName('smartlook_tracking_account', t('A valid Smartlook ID must be 40 characters long.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $smartlook_id = $form_state->getValue('smartlook_tracking_account');

    $config = $this->config('smartlook_tracking.settings');
    $config->set('account', $smartlook_id)->save();

    parent::submitForm($form, $form_state);
  }

}
